package com.fs.his.service;

import java.util.List;
import com.fs.his.domain.FsMaterial;

/**
 * 素材库Service接口
 * 
 * @author fs
 * @date 2023-07-06
 */
public interface IFsMaterialService 
{
    /**
     * 查询素材库
     * 
     * @param materialId 素材库主键
     * @return 素材库
     */
    public FsMaterial selectFsMaterialByMaterialId(Long materialId);

    /**
     * 查询素材库列表
     * 
     * @param fsMaterial 素材库
     * @return 素材库集合
     */
    public List<FsMaterial> selectFsMaterialList(FsMaterial fsMaterial);

    /**
     * 新增素材库
     * 
     * @param fsMaterial 素材库
     * @return 结果
     */
    public int insertFsMaterial(FsMaterial fsMaterial);

    /**
     * 修改素材库
     * 
     * @param fsMaterial 素材库
     * @return 结果
     */
    public int updateFsMaterial(FsMaterial fsMaterial);

    /**
     * 批量删除素材库
     * 
     * @param materialIds 需要删除的素材库主键集合
     * @return 结果
     */
    public int deleteFsMaterialByMaterialIds(Long[] materialIds);

    /**
     * 删除素材库信息
     * 
     * @param materialId 素材库主键
     * @return 结果
     */
    public int deleteFsMaterialByMaterialId(Long materialId);
}
